/*
	links.cpp - A Link Creator
	Copyright (C) 2004  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "links.h"
#include "mmainwindow.h"

#include <qfile.h>
#include <qhbox.h>
#include <qlabel.h>
#include <qlayout.h>

#include <kdesktopfile.h>
#include <kglobalsettings.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kmessagebox.h>
#include <kpushbutton.h>
#include <kstandarddirs.h>

/* public */

Links::Links(QWidget *parent, const char *name)
	: QWidget(parent, name)
{
	QVBoxLayout *l = new QVBoxLayout(this, 2);

	// location
	QHBox *locationBox = new QHBox(this);
	locationBox->setSpacing(2);
	QLabel *l_location =
		new QLabel(i18n("Locatio&n:"), locationBox, "QLabel::l_location");
	l_location->setAlignment(AlignVCenter | AlignRight);
	cb_location = new QComboBox(locationBox, "QComboBox::cb_location");
	cb_location->insertItem(SmallIcon("desktop"), i18n("Desktop"));
	cb_location->insertItem(SmallIcon("kmenu"), i18n("K Menu"));
	l_location->setBuddy(cb_location);
	l->addWidget(locationBox);

	// type
	QHBox *typeBox = new QHBox(this);
	typeBox->setSpacing(2);
	QLabel *l_type = new QLabel(i18n("&Type:"), typeBox, "QLabel::l_type");
	l_type->setAlignment(AlignVCenter | AlignRight);
	cb_type = new QComboBox(typeBox, "QComboBox::cb_type");
	cb_type->insertItem(i18n("KShutDown"));
	cb_type->insertItem(i18n("KShutDown Wizard"));
	cb_type->insertItem(i18n("Standard Logout Dialog"));
	l_type->setBuddy(cb_type);
	l->addWidget(typeBox);

	// buttons
	QHBox *buttonsBox = new QHBox(this);
	buttonsBox->setSpacing(2);

	// create link
	KPushButton *b_createLink = new KPushButton(SmallIcon("filenew"),
		i18n("Cr&eate Link"), buttonsBox, "KPushButton::b_createLink");
	connect(
		b_createLink, SIGNAL(clicked()),
		this, SLOT(createLinkSlot()));

	// remove link
	KPushButton *b_removeLink = new KPushButton(SmallIcon("editdelete"),
		i18n("&Remove Link"), buttonsBox, "KPushButton::b_removeLink");
	connect(
		b_removeLink, SIGNAL(clicked()),
		this, SLOT(removeLinkSlot()));

	l->addWidget(buttonsBox);
}

void Links::createLink(const QString &path, const QString &command,
	const QString &icon, const QString &name)
{
// TODO: 0.5: error message
	if (path.isNull())
		return;

	KDesktopFile *df = new KDesktopFile(path);
	df->setGroup("Desktop Entry");
	df->writeEntry("Encoding", "UTF-8");
	df->writeEntry("Exec", command);
	df->writeEntry("Icon", icon);
	if (!name.isNull())
		df->writeEntry("Name", name);
	df->writeEntry("StartupNotify", "false");
	df->writeEntry("Type", "Application");
	delete df;
}

void Links::removeLink(const QString &path)
{
	if (QFile::exists(path) && !QFile::remove(path))
	{
		KMessageBox::error(
			mainWindow,
			"<qt>" +
			QString(i18n("Could not remove file <b>%1</b>!"))
				.arg(path) +
			"</qt>"
		);
	}
}

/* private */

QString Links::getCurrentLocationPath() const
{
	QString path;
	switch (cb_location->currentItem())
	{
		case 0:
			path = KGlobalSettings::desktopPath() + "/";
			break;
		case 1:
			path = locateLocal("apps", "") + "/";
			break;
		default:
			return QString::null;
	}

	switch (cb_type->currentItem())
	{
		case 0: return path += "kshutdown-classic.desktop";
		case 1: return path += "kshutdown-wizard.desktop";
		case 2: return path += "kshutdown-standard.desktop";
		default: return QString::null;
	}
}

QString Links::getCurrentTypeCommand() const
{
	switch (cb_type->currentItem())
	{
		case 0: return "kshutdown";
		case 1: return "kshutdown --wizard";
		case 2: return "kshutdown --standard";
		default: return QString::null;
	}
}

QString Links::getCurrentTypeIcon() const
{
	switch (cb_type->currentItem())
	{
		case 0: return "kshutdown";
		case 1: return "kshutdown";
		case 2: return "exit";
		default: return QString::null;
	}
}

/* private slots */

void Links::createLinkSlot()
{
	createLink(
		getCurrentLocationPath(),
		getCurrentTypeCommand(),
		getCurrentTypeIcon(),
		cb_type->currentItem() == 2 ? i18n("Logout") : cb_type->currentText()
	);
}

void Links::removeLinkSlot()
{
	removeLink(getCurrentLocationPath());
}
