/*
	mactioneditsdialog.h - action edit dialog
	Copyright (C) 2003  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __MACTIONEDITDIALOG_H__
#define __MACTIONEDITDIALOG_H__

#include "mmainwindow.h"

#include <kdialogbase.h>
#include <klineedit.h>

/**
 * @short An action editor.
 * Used in @ref MSettingsDialog.
 */
class MActionEditDialog: public KDialogBase
{
	Q_OBJECT
public:
	KLineEdit
		/** Default or user command. */
		*command;
	QComboBox
		/** Action methods. */
		*methods;

	/**
	 * Constructor.
	 * @param parent A parent widget
	 * @param name A widget name
	 */
	MActionEditDialog(QWidget *parent = 0, const char *name = 0);

	/** Destructor. */
	virtual ~MActionEditDialog();

	/** Sets current action to @p value. */
	void setAction(const MMainWindow::What value);

	/** Sets current method to @p value. */
	void setActionMethod(const MMainWindow::Method value) const;

	/** Sets user command to @p value. Called from @ref MSettingsDialog. */
	inline void setUserCommand(const QString &value) { _userCommand = value; }
private:
	QLabel
		*l_what,
		*l_command;
	QString _userCommand;
private slots:
	void methodChangeSlot(int index);
};

#endif // __MACTIONEDITDIALOG_H__
