/*
	miscutils.h - Misc Utils
	Copyright (C) 2004  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __MISCUTILS_H__
#define __MISCUTILS_H__

#include "mmainwindow.h"

/** @short Misc. functions. */
class MiscUtils
{
public:
	/**
	 * Displays a confirmation message box to confirm the selected action.
	 * @param action An action to confirm
	 * @return @c TRUE if action has been confirmed; otherwise @c FALSE
	 */
	static bool confirmAction(const MMainWindow::What action);

	/**
	 * Converts seconds to time string.
	 * @param secs Seconds to convert
	 * @param format A date/time format
	 * @return Converted seconds or ">24", if @p secs >= 86400
	 */
	static QString formatDateTime(const int secs,
		const QString &format = QString::null);

	/**
	 * Converts seconds to time string.
	 * @param dt A date/time to convert
	 * @return Converted seconds or ">24", if @p secs >= 86400
	 */
	static QString formatDateTime(const QDateTime &dt);

	/** Returns @c TRUE if @c action is not disabled by KIOSK. */
	static bool isActionEnabled(const MMainWindow::What action);

	/**
	 * A sound notification.
	 * @param name A event name
	 * @code
	 * playSound("kshutdown-one");
	 * @endcode
	 */
	static void playSound(const QString &name);

	/**
	 * Executes a command.
	 * @param command A command to execute
	 * @return @c TRUE if successfull; otherwise @c FALSE
	 */
	static bool runCommand(const QString &command);

	/**
	 * Executes a command with an optional pause.
	 * This function doesn't display an error message box.
	 * @param command A command to execute
	 * @param pause A pause after command execution
	 * @return @c TRUE if successfull; otherwise @c FALSE
	 */
	static bool runCommandWithPause(const QString &command, const int pause);

	/** Sets "tool tip text" and "what's this text" of @p widget to @p value. */
	static void setHint(QWidget *widget, const QString &value);

	/**
	 * Displays a "KRun" error message.
	 * @param command A command name that failed
	 */
	static void showRunErrorMessage(const QString &command);
};

#endif // __MISCUTILS_H__
